from setuptools import setup
from io import open
import os

pwd = os.path.abspath(os.path.dirname(__file__))

VERSION = os.environ.get('CI_COMMIT_TAG', '0.0.0')

REQUIRES = [
    'htmlmin',
]

description = open(os.path.join(pwd, 'readme.rst'), encoding='utf-8').read()

setup(
    name='pelican-htmlmin',
    packages=['pelican_htmlmin'],

    version=VERSION,
    url='https://gitlab.com/bryanbrattlof/pelican-htmlmin',

    description="Minifies HTML files generated by Pelican",
    long_description=description,

    author='Bryan Brattlof',
    author_email='hello@bryanbrattlof.com',

    license='MIT',

    install_requires=REQUIRES,

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 5 - Production/Stable',

        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries',

        'Framework :: Pelican',
        'Framework :: Pelican :: Plugins',

        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',

        'Natural Language :: English',
    ],
)
